@@ -280,6 +280,11 @@ static bool isNonDeletedKey(KEntryMapConstIterator entryMapIt)
 {
     return !entryMapIt->first.mKey.isNull() && !entryMapIt->second.bDeleted;
 }
+// is a key without default values and not deleted
+static bool isSetKey(KEntryMapConstIterator entryMapIt)
+{
+    return !entryMapIt->first.bDefault && !entryMapIt->second.bDeleted;
+}
 
 static int findFirstGroupEndPos(const QString &groupFullName, int from = 0)
 {
@@ -353,23 +358,30 @@ bool KConfigPrivate::hasNonDeletedEntries(const QString &group) const
 
 QList<QByteArray> KConfigPrivate::keyListImpl(const QString &theGroup) const
 {
-    QList<QByteArray> keys;
+    std::set<QByteArray> tmp; // unique set, sorted for unittests
 
-    const auto theEnd = entryMap.cend();
-    auto it = entryMap.constFindEntry(theGroup);
-    if (it != theEnd) {
-        ++it; // advance past the special group entry marker
-
-        std::set<QByteArray> tmp; // unique set, sorted for unittests
-        for (; it != theEnd && it->first.mGroup == theGroup; ++it) {
-            if (isNonDeletedKey(it)) {
-                tmp.insert(it->first.mKey);
-            }
+    entryMap.forEachEntryOfGroup(theGroup, [&tmp](KEntryMapConstIterator it) {
+        if (isNonDeletedKey(it)) {
+            tmp.insert(it->first.mKey);
         }
-        keys = QList<QByteArray>(tmp.begin(), tmp.end());
-    }
+    });
 
-    return keys;
+    return QList<QByteArray>(tmp.begin(), tmp.end());
+}
+
+QStringList KConfigPrivate::usedKeyList(const QString &theGroup) const
+{
+    std::set<QString> tmp; // unique set, sorting as side-effect
+
+    entryMap.forEachEntryOfGroup(theGroup, [&tmp](KEntryMapConstIterator it) {
+        // leave the default values and deleted entries out, same as KConfig::entryMap()
+        if (isSetKey(it)) {
+            const QString key = QString::fromUtf8(it->first.mKey);
+            tmp.insert(key);
+        }
+    });
+
+    return QStringList(tmp.begin(), tmp.end());
 }
 
 QMap<QString, QString> KConfig::entryMap(const QString &aGroup) const
@@ -378,27 +390,21 @@ QMap<QString, QString> KConfig::entryMap(const QString &aGroup) const
     QMap<QString, QString> theMap;
     const QString theGroup = aGroup.isEmpty() ? QStringLiteral("<default>") : aGroup;
 
-    const auto theEnd = d->entryMap.cend();
-    auto it = d->entryMap.constFindEntry(theGroup, {}, {});
-    if (it != theEnd) {
-        ++it; // advance past the special group entry marker
-
-        for (; it != theEnd && it->first.mGroup == theGroup; ++it) {
-            // leave the default values and deleted entries out
-            if (!it->second.bDeleted && !it->first.bDefault) {
-                const QString key = QString::fromUtf8(it->first.mKey.constData());
-                // the localized entry should come first, so don't overwrite it
-                // with the non-localized entry
-                if (!theMap.contains(key)) {
-                    if (it->second.bExpand) {
-                        theMap.insert(key, KConfigPrivate::expandString(QString::fromUtf8(it->second.mValue.constData())));
-                    } else {
-                        theMap.insert(key, QString::fromUtf8(it->second.mValue.constData()));
-                    }
+    d->entryMap.forEachEntryOfGroup(theGroup, [&theMap](KEntryMapConstIterator it) {
+        // leave the default values and deleted entries out
+        if (isSetKey(it)) {
+            const QString key = QString::fromUtf8(it->first.mKey.constData());
+            // the localized entry should come first, so don't overwrite it
+            // with the non-localized entry
+            if (!theMap.contains(key)) {
+                if (it->second.bExpand) {
+                    theMap.insert(key, KConfigPrivate::expandString(QString::fromUtf8(it->second.mValue.constData())));
+                } else {
+                    theMap.insert(key, QString::fromUtf8(it->second.mValue.constData()));
                 }
             }
         }
-    }
+    });
 
     return theMap;
 }
@@ -916,7 +922,7 @@ void KConfig::deleteGroupImpl(const QString &aGroup, WriteConfigFlags flags)
     for (const QString &group : groups) {
         const QList<QByteArray> keys = d->keyListImpl(group);
         for (const QByteArray &key : keys) {
-            if (d->canWriteEntry(group, key.constData())) {
+            if (d->canWriteEntry(group, key)) {
                 d->entryMap.setEntry(group, key, QByteArray(), options);
                 d->bDirty = true;
             }
@@ -958,7 +964,7 @@ bool KConfig::hasGroupImpl(const QString &aGroup) const
     return d->hasNonDeletedEntries(aGroup);
 }
 
-bool KConfigPrivate::canWriteEntry(const QString &group, const char *key, bool isDefault) const
+bool KConfigPrivate::canWriteEntry(const QString &group, QAnyStringView key, bool isDefault) const
 {
     if (bFileImmutable || entryMap.getEntryOption(group, key, KEntryMap::SearchLocalized, KEntryMap::EntryImmutable)) {
         return isDefault;
@@ -987,7 +993,7 @@ void KConfigPrivate::putData(const QString &group, const char *key, const QByteA
     }
 }
 
-void KConfigPrivate::revertEntry(const QString &group, const char *key, KConfigBase::WriteConfigFlags flags)
+void KConfigPrivate::revertEntry(const QString &group, QAnyStringView key, KConfigBase::WriteConfigFlags flags)
 {
     KEntryMap::EntryOptions options = convertToOptions(flags);
 
@@ -997,12 +1003,12 @@ void KConfigPrivate::revertEntry(const QString &group, const char *key, KConfigB
     }
 }
 
-QByteArray KConfigPrivate::lookupData(const QString &group, const char *key, KEntryMap::SearchFlags flags) const
+QByteArray KConfigPrivate::lookupData(const QString &group, QAnyStringView key, KEntryMap::SearchFlags flags) const
 {
     return lookupInternalEntry(group, key, flags).mValue;
 }
 
-KEntry KConfigPrivate::lookupInternalEntry(const QString &group, const char *key, KEntryMap::SearchFlags flags) const
+KEntry KConfigPrivate::lookupInternalEntry(const QString &group, QAnyStringView key, KEntryMap::SearchFlags flags) const
 {
     if (bReadDefaults) {
         flags |= KEntryMap::SearchDefaults;
@@ -1014,7 +1020,7 @@ KEntry KConfigPrivate::lookupInternalEntry(const QString &group, const char *key
     return it->second;
 }
 
-QString KConfigPrivate::lookupData(const QString &group, const char *key, KEntryMap::SearchFlags flags, bool *expand) const
+QString KConfigPrivate::lookupData(const QString &group, QAnyStringView key, KEntryMap::SearchFlags flags, bool *expand) const
 {
     if (bReadDefaults) {
         flags |= KEntryMap::SearchDefaults;
